@@ -55,12 +55,12 @@ class TestNameAwareTestResult(TextTestResult):
 
     def addError(self, test, err):
         exception_type, exception, traceback = err
-        self.failed_test_names_and_reasons[test] = '{0}: {1}'.format(exception_type, exception)
+        self.failed_test_names_and_reasons[test] = '{0}: {1}'.format(exception_type, exception).replace('\'', '')
         super(TestNameAwareTestResult, self).addError(test, err)
 
     def addFailure(self, test, err):
         exception_type, exception, traceback = err
-        self.failed_test_names_and_reasons[test] = '{0}: {1}'.format(exception_type, exception)
+        self.failed_test_names_and_reasons[test] = '{0}: {1}'.format(exception_type, exception).replace('\'', '')
         super(TestNameAwareTestResult, self).addFailure(test, err)
 
 
